@@ -21,6 +21,10 @@ def test_search_topic():
     result = api.get_topics(name="CVE-2020-10560")
     assert result[0]['id'] == "6f81bc44-c000-427d-b222-b64c29bda621"
 
+def test_search_topic_params():
+    result = api.get_assessments(topicId='131226a6-a1e9-48a1-a5d0-ac94baf8dfd2', page=0, size=2, sort="score:asc")
+    assert len(result) == 2
+
 def test_single_topic_fail():
     with pytest.raises(ApiError):
         result = api.get_single_topic('not a uuid')
@@ -30,8 +34,8 @@ def test_single_assesment():
     assert result['id'] == '7c324b6e-0d83-4392-a79f-b61220ebfff3'
 
 def test_multi_assesment():
-    result = api.get_assessments(topicId='131226a6-a1e9-48a1-a5d0-ac94baf8dfd2', page=0, size=2)
-    assert len(result) == 2
+    result = api.get_assessments(topicId='131226a6-a1e9-48a1-a5d0-ac94baf8dfd2')
+    assert len(result) >=2
 
 def test_single_assesment_fail():
     with pytest.raises(ApiError):
